"use strict";
/**
 * @module sybase-interfaces-loader
 */
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var readline = require("readline");
// tslint:disable-next-line:prefer-const
var hosts = {};
function isEmpty(obj) {
    return Object.keys(obj).length === 0;
}
function trimLeft(str) {
    var leadingWhitespace = /^[\s\t]*/;
    return str.replace(leadingWhitespace, '');
}
function locateInterfacesFile() {
    if (process.env.IFILE != null) {
        return process.env.IFILE;
    }
    else if (process.env.SYBASE != null) {
        return path.join(process.env.SYBASE, 'interfaces');
    }
    else {
        return '/usr/local/sybase/interfaces';
    }
}
function loadInterfaces() {
    if (!isEmpty(hosts)) {
        return hosts;
    }
    var rl = readline.createInterface({
        input: fs.createReadStream(locateInterfacesFile())
    });
    var lines = fs.readFileSync(locateInterfacesFile()).toString().split('\n');
    var serverName = '';
    lines.forEach(function (line) {
        if (/^\S/.test(line)) {
            var parts = line.split(' ');
            serverName = parts[0];
            hosts[serverName] = [];
        }
        else if (/^\s+/.test(line)) {
            var parts = trimLeft(line).split(' ');
            hosts[serverName].push({
                serviceType: parts[0],
                protocol: parts[1],
                network: parts[2],
                machine: parts[3],
                port: parts[4],
                filter: parts[5]
            });
        }
    });
    return hosts;
}
function passesFilter(entry, filter) {
    if (filter === void 0) { filter = {}; }
    return Object.keys(filter).every(function (key) { return (entry[key] === filter[key]); });
}
function filterEntries(serverName, filter) {
    if (filter === void 0) { filter = {}; }
    var h = loadInterfaces();
    var allEntries = h[serverName] || [];
    return allEntries.filter(function (m) { return passesFilter(m, filter); });
}
exports.filterEntries = filterEntries;
function findEntry(serverName, filter) {
    if (filter === void 0) { filter = {}; }
    var h = loadInterfaces();
    var allEntries = h[serverName];
    if (allEntries == null) {
        return undefined;
    }
    else {
        return allEntries.find(function (m) { return passesFilter(m, filter); });
    }
}
exports.findEntry = findEntry;
