"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * test
 */
var chai_1 = require("chai");
var mock = require("mock-fs");
var src_1 = require("../src");
var expectedMasterEntry = {
    serviceType: 'master',
    protocol: 'tcp',
    network: 'ether',
    machine: 'alpha.example.com',
    port: '4100',
    filter: undefined
};
var expectedQueryEntry = __assign({}, expectedMasterEntry, { serviceType: 'query' });
var interfacesFileContent = "alpha\n\tmaster tcp ether alpha.example.com 4100\n\tquery tcp ether alpha.example.com 4100\nbeta\n\tmaster tcp ether beta.example.com 4100\n\tquery tcp ether beta.example.com 4100\ngamma\n\tmaster tcp ether gamma.example.com 4100\n\tquery tcp ether gamma.example.com 4100\n";
function mockInterfacesFile() {
    mock({
        '/usr/local/sybase/interfaces': interfacesFileContent
    });
    delete process.env.SYBASE;
    delete process.env.IFILE;
}
function restoreInterfacesFile() {
    mock.restore();
}
describe('filterEntries', function () {
    before(mockInterfacesFile);
    after(restoreInterfacesFile);
    it('should retrieve the master and query entries when both exist', function () {
        var entries = src_1.filterEntries('alpha');
        chai_1.assert.lengthOf(entries, 2, 'entries length is 2');
        var masterEntry = entries.find(function (e) { return e.serviceType === 'master'; });
        var queryEntry = entries.find(function (e) { return e.serviceType === 'query'; });
        chai_1.assert.deepEqual(masterEntry, expectedMasterEntry);
        chai_1.assert.deepEqual(queryEntry, expectedQueryEntry);
    });
    it('should do something about IFILE', function () {
        chai_1.assert.equal(process.env.IFILE, null, 'blah');
    });
});
describe('findEntry', function () {
    before(mockInterfacesFile);
    after(restoreInterfacesFile);
    it('should return the first matching entry matching', function () {
        var entry = src_1.findEntry('alpha');
        chai_1.assert.deepEqual(entry, expectedMasterEntry);
    });
    it('should respect filters to match entries', function () {
        var entry = src_1.findEntry('alpha', { serviceType: 'query' });
        chai_1.assert.deepEqual(entry, expectedQueryEntry);
    });
    it('should return undefined when no entry is found', function () {
        var entry = src_1.findEntry('delta');
        chai_1.assert.notExists(entry, 'entry does not exist');
    });
});
